pygerber.parser.pillow.apertures package
========================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   pygerber.parser.pillow.apertures.arc_mixin
   pygerber.parser.pillow.apertures.circle
   pygerber.parser.pillow.apertures.custom
   pygerber.parser.pillow.apertures.flash_line_mixin
   pygerber.parser.pillow.apertures.flash_mixin
   pygerber.parser.pillow.apertures.obround
   pygerber.parser.pillow.apertures.polygon
   pygerber.parser.pillow.apertures.rectangle
   pygerber.parser.pillow.apertures.region
   pygerber.parser.pillow.apertures.util

Module contents
---------------

.. automodule:: pygerber.parser.pillow.apertures
   :members:
   :undoc-members:
   :show-inheritance:
